@@ -48,6 +48,7 @@
 
 class CityGMLOSGPluginLogger : public citygml::CityGMLLogger {
 public:
+
     virtual void log(LOGLEVEL level, const std::string& message, const char* file, int line) const
     {
         std::ostream& stream = getLogStreamFor(level);
@@ -63,10 +64,6 @@ public:
         stream << " " << message << std::endl;
     }
 
-    virtual bool isEnabledFor(LOGLEVEL) const
-    {
-        return true;
-    }
 private:
     std::ostream& getLogStreamFor(LOGLEVEL level) const {
         switch(level) {
@@ -398,9 +395,12 @@ void createOsgGeometryFromCityGMLGeometry(const citygml::Geometry& geometry, Cit
         setMaterial(stateset, p, settings);
         setTexture(stateset, geom, p, settings);
 
-        if (settings._storeGeomIDs) {
-            geom->addDescription(p.getId());
-        }
+#if OSG_VERSION_GREATER_OR_EQUAL(3,3,2)
+            if (settings._storeGeomIDs) {
+                geom->addDescription(p.getId());
+            }
+#endif
+
 
         geometryContainer->addDrawable( geom );
     }
