@@ -84,6 +84,22 @@ namespace citygml {
 
         void finish(Tesselator& tesselator , bool optimize, std::shared_ptr<CityGMLLogger> logger);
 
+        std::shared_ptr<LinearRing> exteriorRing(){
+            return m_exteriorRing;
+        }
+
+        const std::shared_ptr<LinearRing> exteriorRing() const{
+            return m_exteriorRing;
+        }
+
+        std::vector<std::shared_ptr<LinearRing> >& interiorRings() {
+            return m_interiorRings;
+        }
+
+        const std::vector<std::shared_ptr<LinearRing> >& interiorRings() const{
+            return m_interiorRings;
+        }
+
         virtual ~Polygon();
 
     protected:
@@ -106,12 +122,12 @@ namespace citygml {
         TVec3d computeNormal();
 
         std::vector<TVec3d> m_vertices;
-        std::unordered_map<std::string, std::vector<TVec2f>> m_themeToFrontTexCoordsMap;
-        std::unordered_map<std::string, std::vector<TVec2f>> m_themeToBackTexCoordsMap;
+        std::unordered_map<std::string, std::vector<TVec2f> > m_themeToFrontTexCoordsMap;
+        std::unordered_map<std::string, std::vector<TVec2f> > m_themeToBackTexCoordsMap;
         std::vector<unsigned int> m_indices;
 
-        std::unique_ptr<LinearRing> m_exteriorRing;
-        std::vector<std::unique_ptr<LinearRing>> m_interiorRings;
+        std::shared_ptr<LinearRing> m_exteriorRing;
+        std::vector<std::shared_ptr<LinearRing> > m_interiorRings;
 
         bool m_negNormal;
         bool m_finished;
