@@ -30,6 +30,7 @@
   #include <GL/glu.h>
 #endif
 
+#include <citygml/citygml_api.h>
 #include <citygml/vecs.hpp>
 #include <vector>
 #include <list>
@@ -40,7 +41,7 @@ namespace citygml {
 }
 
 // GLU based polygon tesselator
-class Tesselator
+class LIBCITYGML_EXPORT Tesselator
 {
 public:
     Tesselator( std::shared_ptr<citygml::CityGMLLogger> logger );
@@ -62,6 +63,9 @@ public:
     const std::vector<std::vector<TVec2f> >& getTexCoords() const { return _texCoordsLists; }
     const std::vector<unsigned int>& getIndices() const;
 
+    void setKeepVertices(bool val);
+    bool keepVertices() const;
+
 private:
     typedef void (APIENTRY *GLU_TESS_CALLBACK)();
     static void CALLBACK beginCallback( GLenum, void* );
@@ -81,6 +85,8 @@ private:
 
     std::vector<unsigned int> _curIndices;
     std::shared_ptr<citygml::CityGMLLogger> _logger;
+
+    bool _keepVertices;
 };
 
 #endif // __TESSELATOR_H__
