@@ -11,9 +11,9 @@
 #include "parser/linestringelementparser.h"
 #include "parser/addressparser.h"
 
-#include "citygml/citygmlfactory.h"
-#include "citygml/citygmllogger.h"
-#include "citygml/address.h"
+#include <citygml/citygmlfactory.h>
+#include <citygml/citygmllogger.h>
+#include <citygml/address.h>
 
 #include <stdexcept>
 #include <iostream>
@@ -25,16 +25,18 @@ namespace citygml {
 
     std::unordered_map<int, CityObject::CityObjectsType> CityObjectElementParser::typeIDTypeMap = std::unordered_map<int, CityObject::CityObjectsType>();
     std::unordered_set<int> CityObjectElementParser::attributesSet = std::unordered_set<int>();
+    std::unordered_map<int, AttributeType> CityObjectElementParser::attributeTypeMap;
 
     std::mutex CityObjectElementParser::initializedTypeIDMutex;
     std::mutex CityObjectElementParser::initializedAttributeSetMutex;
 
-    #define HANDLE_TYPE( prefix, elementName ) std::pair<int, CityObject::CityObjectsType>(NodeType::prefix ## _ ## elementName ## Node.typeID(), CityObject::COT_ ## elementName)
+    #define HANDLE_TYPE( prefix, elementName ) std::pair<int, CityObject::CityObjectsType>(NodeType::prefix ## _ ## elementName ## Node.typeID(), CityObject::CityObjectsType::COT_## elementName)
     #define HANDLE_GROUP_TYPE( prefix, elementName, enumtype ) std::pair<int, CityObject::CityObjectsType>(NodeType::prefix ## _ ## elementName ## Node.typeID(), enumtype)
     #define HANDLE_ATTR( prefix, elementName ) NodeType::prefix ## _ ## elementName ## Node.typeID()
 
     CityObjectElementParser::CityObjectElementParser(CityGMLDocumentParser& documentParser, CityGMLFactory& factory, std::shared_ptr<CityGMLLogger> logger, std::function<void (CityObject*)> callback)
         : GMLFeatureCollectionElementParser(documentParser, factory, logger)
+        , m_lastAttributeType(AttributeType::String)
     {
         m_callback = callback;
     }
@@ -71,9 +73,9 @@ namespace citygml {
                 typeIDTypeMap.insert(HANDLE_TYPE(VEG, PlantCover));
                 typeIDTypeMap.insert(HANDLE_TYPE(VEG, SolitaryVegetationObject));
                 typeIDTypeMap.insert(HANDLE_TYPE(WTR, WaterBody));
-                typeIDTypeMap.insert(HANDLE_GROUP_TYPE(WTR, WaterSurface, CityObject::COT_WaterBody));
-                typeIDTypeMap.insert(HANDLE_GROUP_TYPE(WTR, WaterGroundSurface, CityObject::COT_WaterBody));
-                typeIDTypeMap.insert(HANDLE_GROUP_TYPE(WTR, WaterClosureSurface, CityObject::COT_WaterBody));
+                typeIDTypeMap.insert(HANDLE_GROUP_TYPE(WTR, WaterSurface, CityObject::CityObjectsType::COT_WaterBody));
+                typeIDTypeMap.insert(HANDLE_GROUP_TYPE(WTR, WaterGroundSurface, CityObject::CityObjectsType::COT_WaterBody));
+                typeIDTypeMap.insert(HANDLE_GROUP_TYPE(WTR, WaterClosureSurface, CityObject::CityObjectsType::COT_WaterBody));
                 typeIDTypeMap.insert(HANDLE_TYPE(LUSE, LandUse));
                 typeIDTypeMap.insert(HANDLE_TYPE(SUB, Tunnel));
                 typeIDTypeMap.insert(HANDLE_TYPE(BRID, Bridge));
@@ -87,6 +89,8 @@ namespace citygml {
                 typeIDTypeMap.insert(HANDLE_TYPE(BLDG, FloorSurface));
                 typeIDTypeMap.insert(HANDLE_TYPE(BLDG, InteriorWallSurface));
                 typeIDTypeMap.insert(HANDLE_TYPE(BLDG, CeilingSurface));
+                typeIDTypeMap.insert(HANDLE_TYPE(BLDG, OuterCeilingSurface));
+                typeIDTypeMap.insert(HANDLE_TYPE(BLDG, OuterFloorSurface));
                 typeIDTypeMap.insert(HANDLE_TYPE(GRP, CityObjectGroup));
                 typeIDTypeMap.insert(HANDLE_TYPE(DEM, ReliefFeature));
 
@@ -143,11 +147,71 @@ namespace citygml {
                 attributesSet.insert(HANDLE_ATTR(WTR, Usage));
                 attributesSet.insert(HANDLE_ATTR(WTR, WaterLevel));
 
+
+                attributeTypeMap[HANDLE_ATTR(CORE, CreationDate)] = AttributeType::Date;
+                attributeTypeMap[HANDLE_ATTR(CORE, TerminationDate)] = AttributeType::Date;
+                attributeTypeMap[HANDLE_ATTR(BLDG, Type)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(BLDG, Class)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(BLDG, Function)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(BLDG, Usage)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(BLDG, YearOfConstruction)] = AttributeType::Date;
+                attributeTypeMap[HANDLE_ATTR(BLDG, YearOfDemolition)] = AttributeType::Date;
+                attributeTypeMap[HANDLE_ATTR(BLDG, StoreyHeightsAboveGround)] = AttributeType::Double;
+                attributeTypeMap[HANDLE_ATTR(BLDG, StoreyHeightsBelowGround)] = AttributeType::Double;
+                attributeTypeMap[HANDLE_ATTR(BLDG, StoreysBelowGround)] = AttributeType::Integer;
+                attributeTypeMap[HANDLE_ATTR(BLDG, StoreysAboveGround)] = AttributeType::Integer;
+                attributeTypeMap[HANDLE_ATTR(BLDG, MeasuredHeight)] = AttributeType::Double;
+                attributeTypeMap[HANDLE_ATTR(BLDG, RoofType)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(VEG, Class )] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(VEG, Function )] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(VEG, AverageHeight )] = AttributeType::Double;
+                attributeTypeMap[HANDLE_ATTR(VEG, Species )] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(VEG, Height )] = AttributeType::Double;
+                attributeTypeMap[HANDLE_ATTR(VEG, TrunkDiameter )] = AttributeType::Double;
+                attributeTypeMap[HANDLE_ATTR(VEG, CrownDiameter )] = AttributeType::Double;
+                attributeTypeMap[HANDLE_ATTR(FRN, Class)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(FRN, Function)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(GRP, Class)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(GRP, Function)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(GRP, Usage)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(GEN, Class)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(GEN, Function)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(GEN, Usage)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(LUSE, Class)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(LUSE, Function)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(LUSE, Usage)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(DEM, Lod)] = AttributeType::Integer;
+                attributeTypeMap[HANDLE_ATTR(TRANS, Usage)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(TRANS, Function)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(TRANS, SurfaceMaterial)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(WTR, Class)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(WTR, Function)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(WTR, Usage)] = AttributeType::String;
+                attributeTypeMap[HANDLE_ATTR(WTR, WaterLevel)] = AttributeType::Double;
+
                 attributesSetInitialized = true;
             }
         }
     }
 
+    AttributeType CityObjectElementParser::getAttributeType(const NodeType::XMLNode& node)
+    {
+        if (node == NodeType::GEN_StringAttributeNode) {
+            return AttributeType::String;
+        } else if (node == NodeType::GEN_DoubleAttributeNode) {
+            return AttributeType::Double;
+        } else if (node == NodeType::GEN_IntAttributeNode) {
+            return AttributeType::Integer;
+        } else if (node == NodeType::GEN_DateAttributeNode) {
+            return AttributeType::Date;
+        } else if (node == NodeType::GEN_UriAttributeNode) {
+            return AttributeType::Uri;
+        } else {
+            // fallback to string for other types
+            return AttributeType::String;
+        }
+    }
+
     bool CityObjectElementParser::handlesElement(const NodeType::XMLNode& node) const
     {
         initializeTypeIDTypeMap();
@@ -193,7 +257,7 @@ namespace citygml {
              || node == NodeType::GEN_UriAttributeNode) {
 
             m_lastAttributeName = attributes.getAttribute("name");
-
+            m_lastAttributeType = getAttributeType(node);
         } else if (attributesSet.count(node.typeID()) > 0 || node == NodeType::GEN_ValueNode) {
 
             return true;
@@ -349,12 +413,13 @@ namespace citygml {
              || node == NodeType::GEN_UriAttributeNode) {
 
             m_lastAttributeName = "";
-            return true;
+            m_lastAttributeType = AttributeType::String;
 
+            return true;
         } else if (node == NodeType::GEN_ValueNode) {
 
             if (!m_lastAttributeName.empty()) {
-                m_model->setAttribute(m_lastAttributeName, characters);
+                m_model->setAttribute(m_lastAttributeName, characters, m_lastAttributeType);
             } else {
                 CITYGML_LOG_WARN(m_logger, "Found value node (" << NodeType::GEN_ValueNode << ") outside attribute node... ignore.");
             }
@@ -362,7 +427,7 @@ namespace citygml {
             return true;
         } else if (attributesSet.count(node.typeID()) > 0) {
             if (!characters.empty()) {
-                m_model->setAttribute(node.name(), characters);
+                m_model->setAttribute(node.name(), characters, attributeTypeMap.at(node.typeID()));
             }
             return true;
         } else if (node == NodeType::BLDG_BoundedByNode
